==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Сховище не доступне",
    "Storage invalid" : "Неправильне сховище",
    "Unknown error" : "Невідома помилка",
    "Could not move %s - File with this name already exists" : "Не вдалося перемістити %s - файл з таким ім'ям вже існує",
    "Could not move %s" : "Не вдалося перемістити %s",
    "Permission denied" : "Доступ заборонено",
    "The target folder has been moved or deleted." : "Теку призначення було переміщено або видалено.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Файл з ім'ям %s вже є у теці %s. Оберіть інше ім'я.",
    "Error when creating the file" : "Помилка створення файлу",
    "Error when creating the folder" : "Помилка створення теки",
    "Unable to set upload directory." : "Не вдалося встановити каталог вивантаження.",
    "Invalid Token" : "Неприпустимий маркер",
    "No file was uploaded. Unknown error" : "Файл не був вивантажений. Невідома помилка",
    "There is no error, the file uploaded with success" : "Файл успішно вивантажений. Помилок немає.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Розмір вивантаження перевищує значення параметра upload_max_filesize в php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The uploaded file was only partially uploaded" : "Файл вивантажений лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Failed to write to disk" : "Помилка запису на диск",
    "Not enough storage available" : "Місця більше немає",
    "Upload failed. Could not find uploaded file" : "Вивантаження не вдалося. Неможливо знайти вивантажений файл.",
    "Upload failed. Could not get file info." : "Вивантаження не вдалося. Неможливо отримати інформацію про файл.",
    "Invalid directory." : "Невірний каталог.",
    "Files" : "Файли",
    "All files" : "Усі файли",
    "Favorites" : "Улюблені",
    "Home" : "Домашня адреса",
    "Close" : "Закрити",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Total file size {size1} exceeds upload limit {size2}" : "Розмір файлу {size1} перевищує обмеження {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Could not get result from server." : "Не вдалося отримати результат від сервера.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Виконується вивантаження файлу. Закриття цієї сторінки приведе до скасування вивантаження.",
    "Actions" : "Дії",
    "Download" : "Завантажити",
    "Rename" : "Перейменувати",
    "Delete" : "Видалити",
    "Details" : "Деталі",
    "Select" : "Оберіть",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "This operation is forbidden" : "Ця операція заборонена",
    "Error moving file." : "Помилка переміщення файлу.",
    "Error moving file" : "Помилка переміщення файлу",
    "Error" : "Помилка",
    "{new_name} already exists" : "{new_name} вже існує",
    "Could not rename file" : "Неможливо перейменувати файл",
    "Could not create file" : "Не вдалося створити файл",
    "Could not create folder" : "Не вдалося створити теку",
    "Error deleting file." : "Помилка видалення файлу.",
    "No entries in this folder match '{filter}'" : "Нічого не знайдено в цій теці  '{filter}'",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "Favorited" : "Улюблений",
    "Favorite" : "Улюблений",
    "Upload" : "Вивантажити",
    "Text file" : "Текстовий файл",
    "Folder" : "Тека",
    "New folder" : "Нова тека",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл або теку було <strong> змінено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "You created %1$s" : "Вами створено %1$s",
    "%2$s created %1$s" : "%2$s створено %1$s",
    "%1$s was created in a public folder" : "%1$s створено у публічній теці",
    "You changed %1$s" : "Вами змінено %1$s",
    "%2$s changed %1$s" : "%2$s змінено %1$s",
    "You deleted %1$s" : "Вами видалено %1$s",
    "%2$s deleted %1$s" : "%2$s видалено %1$s",
    "You restored %1$s" : "Вами відновлено %1$s",
    "%2$s restored %1$s" : "%2$s відновлено %1$s",
    "%s could not be renamed as it has been deleted" : "%s не можна перейменувати, оскільки його видалено",
    "%s could not be renamed" : "%s не можна перейменувати",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "File handling" : "Робота з файлами",
    "Maximum upload size" : "Максимальний розмір вивантажень",
    "max. possible: " : "макс. можливе:",
    "Save" : "Зберегти",
    "Can not be edited from here due to insufficient permissions." : "Неможливо відредагувати тут через брак повноважень.",
    "Settings" : "Налаштування",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Для доступу до файлів через WebDAV використовуйте <a href=\"%s\" target=\"_blank\">це посилання</a>",
    "Cancel upload" : "Скасувати вивантаження",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "Files are being scanned, please wait." : "Файли перевіряються, зачекайте, будь-ласка.",
    "Currently scanning" : "Триває перевірка",
    "No favorites" : "Немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/uk.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Сховище не доступне",
    "Storage invalid" : "Неправильне сховище",
    "Unknown error" : "Невідома помилка",
    "Unable to set upload directory." : "Не вдалося встановити каталог вивантаження.",
    "Invalid Token" : "Неприпустимий маркер",
    "No file was uploaded. Unknown error" : "Файл не був вивантажений. Невідома помилка",
    "There is no error, the file uploaded with success" : "Файл успішно вивантажений. Помилок немає.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Розмір вивантаження перевищує значення параметра upload_max_filesize в php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Розмір вивантаженого файлу перевищує директиву MAX_FILE_SIZE вказану в HTML формі",
    "The uploaded file was only partially uploaded" : "Файл вивантажений лише частково",
    "No file was uploaded" : "Не вивантажено жодного файлу",
    "Missing a temporary folder" : "Відсутній тимчасовий каталог",
    "Failed to write to disk" : "Помилка запису на диск",
    "Not enough storage available" : "Місця більше немає",
    "The target folder has been moved or deleted." : "Теку призначення було переміщено або видалено.",
    "Upload failed. Could not find uploaded file" : "Вивантаження не вдалося. Неможливо знайти вивантажений файл.",
    "Upload failed. Could not get file info." : "Вивантаження не вдалося. Неможливо отримати інформацію про файл.",
    "Invalid directory." : "Невірний каталог.",
    "Files" : "Файли",
    "All files" : "Усі файли",
    "Favorites" : "Улюблені",
    "Home" : "Домашня адреса",
    "Close" : "Закрити",
    "Upload cancelled." : "Вивантаження скасовано.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможливо вивантажити {filename}, оскільки це каталог або файл має розмір 0 байт.",
    "Total file size {size1} exceeds upload limit {size2}" : "Розмір файлу {size1} перевищує обмеження {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостатньо вільного місця, ви вивантажуєте {size1}, а залишилося лише {size2}",
    "Could not get result from server." : "Не вдалося отримати результат від сервера.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Виконується вивантаження файлу. Закриття цієї сторінки приведе до скасування вивантаження.",
    "Actions" : "Дії",
    "Download" : "Завантажити",
    "Rename" : "Перейменувати",
    "Delete" : "Видалити",
    "Disconnect storage" : "Від’єднати сховище",
    "Unshare" : "Закрити спільний доступ",
    "Details" : "Деталі",
    "Select" : "Оберіть",
    "Pending" : "Очікування",
    "Unable to determine date" : "Неможливо визначити дату",
    "This operation is forbidden" : "Ця операція заборонена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорія недоступна, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
    "No entries in this folder match '{filter}'" : "Нічого не знайдено в цій теці  '{filter}'",
    "Name" : "Ім'я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "_%n folder_::_%n folders_" : ["%n тека ","теки : %n ","теки : %n "],
    "_%n file_::_%n files_" : ["%n файл ","файли : %n ","файли : %n "],
    "{dirs} and {files}" : "{dirs} і {files}",
    "You don’t have permission to upload or create files here" : "У вас недостатньо прав для вивантаження або створення тут файлів",
    "_Uploading %n file_::_Uploading %n files_" : ["Вивантаження %n файлу","Вивантаження %n файлів","Вивантаження %n файлів"],
    "New" : "Створити",
    "\"{name}\" is an invalid file name." : "\"{name}\" - некоректне ім'я файлу.",
    "File name cannot be empty." : " Ім'я файлу не може бути порожнім.",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані !",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше сховище майже повне ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["знайдено '{filter}'","знайдено '{filter}'","знайдено '{filter}'"],
    "Favorited" : "Улюблений",
    "Favorite" : "Улюблений",
    "Folder" : "Тека",
    "New folder" : "Нова тека",
    "Upload" : "Вивантажити",
    "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
    "A new file or folder has been <strong>created</strong>" : "Новий файл або теку було <strong>створено</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл або теку було <strong> змінено </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Обмежити повідомлення про створення та зміни в ваших <strong>улюблених файлах</strong>\n<em>(Тількі потік)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл або теку було <strong> видалено </strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл або теку було <strong> відновлено </strong>",
    "You created %1$s" : "Вами створено %1$s",
    "%2$s created %1$s" : "%2$s створено %1$s",
    "%1$s was created in a public folder" : "%1$s створено у публічній теці",
    "You changed %1$s" : "Вами змінено %1$s",
    "%2$s changed %1$s" : "%2$s змінено %1$s",
    "You deleted %1$s" : "Вами видалено %1$s",
    "%2$s deleted %1$s" : "%2$s видалено %1$s",
    "You restored %1$s" : "Вами відновлено %1$s",
    "%2$s restored %1$s" : "%2$s відновлено %1$s",
    "Upload (max. %s)" : "Вивантаження (макс. %s)",
    "File handling" : "Робота з файлами",
    "Maximum upload size" : "Максимальний розмір вивантажень",
    "max. possible: " : "макс. можливе:",
    "Save" : "Зберегти",
    "Settings" : "Налаштування",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Для доступу до файлів через WebDAV використовуйте <a href=\"%s\" target=\"_blank\">це посилання</a>",
    "Cancel upload" : "Скасувати вивантаження",
    "No files in here" : "Тут немає файлів",
    "Upload some content or sync with your devices!" : "Вивантажте щось або синхронізуйте з пристроями!",
    "No entries found in this folder" : "В цій теці нічого немає",
    "Select all" : "Вибрати всі",
    "Upload too large" : "Файл занадто великий",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли,що ви намагаєтесь вивантажити перевищують максимальний дозволений розмір файлів на цьому сервері.",
    "No favorites" : "Немає улюблених",
    "Files and folders you mark as favorite will show up here" : "Файли і теки, які ви позначили як улюблені, з’являться тут",
    "Text file" : "Текстовий файл"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
